#!/usr/bin/env python3.8
# -*- coding: utf-8 -*-
"""The setup script."""
import setuptools

from bapy import get_requirements, Path, PostDevelopCommand, PostInstallCommand, Url, User

from {{ package }} import m, postcommand

PostDevelopCommand.function = PostInstallCommand.function = postcommand

setup = (
{% for key, value in setup.items() %}
          {{ key }}= {{ value}}
{% endfor %}
)
